@@ -1,7 +1,9 @@
 package Pod::Weaver::Plugin::Sah::Schemas;
 
-our $DATE = '2019-12-17'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
+our $VERSION = '0.060'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -98,6 +100,39 @@ sub weave_section {
             }
             my $sch = ${"$package\::schema"};
 
+            # add POD section: Synopsis
+            {
+                my @pod;
+
+                # examples
+                {
+                    require Data::Dmp;
+                    my $egs = $sch->[1]{examples};
+                    last unless $egs && @$egs;
+                    push @pod, "Sample data:\n\n";
+                    for my $eg (@$egs) {
+                        # XXX if dump is too long, use Data::Dump instead
+                        push @pod, " ", Data::Dmp::dmp($eg->{data});
+                        if ($eg->{valid}) {
+                            push @pod, "  # valid";
+                            push @pod, ", becomes ",
+                                Data::Dmp::dmp($eg->{res})
+                                  if exists $eg->{res};
+                        } else {
+                            push @pod, "  # INVALID";
+                            push @pod, " ($eg->{summary})"
+                                if defined $eg->{summary};
+                        }
+                        push @pod, "\n\n";
+                    } # for eg
+                } # examples
+
+                $self->add_text_to_section(
+                    $document, join("", @pod), 'SYNOPSIS',
+                    {ignore => 1},
+                );
+            }
+
             # add POD section: DESCRIPTION
             {
                 last unless $sch->[1]{description};
@@ -132,7 +167,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.05 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2019-12-17.
+This document describes version 0.060 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2020-03-02.
 
 =head1 SYNOPSIS
 
@@ -193,7 +228,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
